import ij.*;
import ij.plugin.*;
import ij.process.*;

/**
	This plugin concatenates two stacks. Requires that exactly two stacks be 
	open and they have the same width, height and data type. Will also add
	a single image to a stack if the stack is opened first.
    */
public class Stack_Concatenator implements PlugIn {

	public void run(String arg) {
		if (IJ.versionLessThan("1.19z"))
			return;
		int[] list = WindowManager.getIDList();
		if (list==null || list.length!=2)
			{error(); return;}
		ImagePlus imp1 = WindowManager.getImage(list[0]);
		ImagePlus imp2 = WindowManager.getImage(list[1]);
		if (imp1.getType()!=imp2.getType())
			{error(); return;}
		if (imp1.getWidth()!=imp2.getWidth() || imp1.getHeight()!=imp2.getHeight())
			{error(); return;}
		ImageStack stack1 = imp1.getStack();
		ImageStack stack2 = imp2.getStack();
		int size1 = stack1.getSize();
		int size2 = stack2.getSize();
		if (size1==1)
			{error(); return;}
		for (int i=1; i<=size2; i++) {
			ImageProcessor ip = stack2.getProcessor(1);
			String label = stack2.getSliceLabel(1);
			stack1.addSlice(label, ip);
			stack2.deleteSlice(1);
		}
		imp2.changes = false;
		imp2.getWindow().close();
		imp1.repaintWindow();
	}
	
	void error() {
		IJ.showMessage("Stack_Concatenator", "This plugin requires two stacks that have\n"+
			"the same width, height and data type.");
	}

}

